YAHOO.example.Data = {
    apitester: [
        {number:0, date:new Date(1999, 1, 1), string:"1"},
        {number:1, date:new Date(1999, 10, 10), string:"12"},
        {number:2, date:new Date(2000, 1, 1), string:"123"},
        {number:3, date:new Date(2000, 10, 1), string:"10"},
        {number:4, date:new Date(2001, 10, 12), string:"1"},
        {number:5, date:new Date(2001, 1, 12), string:"123"},
        {number:6, date:new Date(2001, 10, 1), string:"11"},
        {number:7, date:new Date(2001, 10, 1), string:"16"},
        {number:8, date:new Date(2001, 10, 1), string:"8"},
        {number:9, date:new Date(2001, 10, 1), string:"6"},
        {number:10, date:new Date(2001, 10, 1), string:"66"},
        {number:11, date:new Date(2001, 10, 1), string:"111"},
        {number:12, date:new Date(2001, 10, 1), string:"110"}
    ],

    multitypes: {
        items: [
            {field1: "bananas", field2:new Date(2007, 1, 1), field3:111, field4:"23.4", field5:"bob", field6:"http://www.yahoo.com"},
            {field1: "cherries", field2:new Date(2006, 1, 1), field3:12.3, field4:"35.12", field5:"ann", field6:"http://www.yahoo.com"},
            {field1: "apples", field2:new Date(2007, 11, 1), field3:1, field4:34.12, field5:"charlie", field6:"http://www.yahoo.com"},
            {field1: "bananas", field2:new Date(2007, 1, 11), field3:1112, field4:"03", field5:"diane", field6:"http://www.yahoo.com"},
            {field1: "cherries", field2:new Date(1999, 1, 11), field3:124, field4:03, field5:"edgar", field6:"http://www.yahoo.com"},
            {field1: "bananas", field2:"January 10, 2005", field3:"12", field4:"34", field5:"francine", field6:"http://www.yahoo.com"},
            {field1: "apples", field2:"January 1, 2005", field3:"19.1", field4:"234.5", field5:"george", field6:"http://www.yahoo.com"},
            {field1: "bananas", field2:"1/11/05", field3:"10.02", field4:"345.654", field5:"hannah", field6:"http://www.yahoo.com"},
            {field1: "cherries", field2:"1/11/2005", field3:"109", field4:23.456, field5:"igor", field6:"http://www.yahoo.com"},
            {field1: "bananas", field2:"November 1, 2005", field3:"11111", field4:23.0123, field5:"julie", field6:"http://www.yahoo.com"}
        ]
    },

    webstats: [
        ["home.html",20,400,44,657],
        ["blog.html",24,377,97,567],
        ["contact.html",32,548,42,543],
        ["about.html",8,465,12,946],
        ["pagenotfound.html",0,0,0,0]
    ],

    emails: {
        account:"jenny@yahoo.com",
        currStorage: 10,
        maxStorage: 200,
        messages: [
            {XID: "9897",Date:new Date(1981, 2, 24),To:"Joe",From:"Jenny",Unread:false,Subject:"Check out my new pictures"},
            {XID: "7899",Date:new Date(1980, 1, 11),To:"Jane",From:"Jenny",Unread:false,Subject:"Let's have lunch"},
            {XID: "6789",Date:new Date(1978, 11, 12),To:"Ann",From:"Jenny",Unread:false,Subject:"Here's the info you requested"},
            {XID: "4996",Date:new Date(1974, 1, 11),To:"Bob",From:"Jenny",Unread:true,Subject:"RE: Let's have lunch"},
            {XID: "4544",Date:new Date(1974, 1, 10),To:"Charlie",From:"Jenny",Unread:false,Subject:"Birthday party Saturday"}
        ]
    },

    inventory: [
        {SKU:"23-23874", Quantity:43, Item:"Helmet", Description:"Red baseball helmet. Size: Large."},
        {SKU:"48-38835", Quantity:84, Item:"Football", Description:"Leather football."},
        {SKU:"84-84848", Quantity:31, Item:"Goggles", Description:"Light blue swim goggles"},
        {SKU:"84-84843", Quantity:56, Item:"Badminton Set", Description:"Set of 2 badminton rackets, net, and 3 birdies."},
        {SKU:"84-39321", Quantity:128, Item:"Tennis Balls", Description:"Canister of 3 tennis balls."},
        {SKU:"39-48949", Quantity:55, Item:"Snowboard", Description:""},
        {SKU:"99-28128", Quantity:77, Item:"Cleats", Description:"Soccer cleats. Size: 10."},
        {SKU:"83-48281", Quantity:65, Item:"Volleyball", Description:""},
        {SKU:"89-32811", Quantity:12, Item:"Sweatband", Description:"Blue sweatband. Size: Medium."},
        {SKU:"28-22847", Quantity:43, Item:"Golf Set", Description:"Set of 9 golf clubs and bag."},
        {SKU:"38-38281", Quantity:1, Item:"Basketball Shorts", Description:"Green basketball shorts. Size: Small."},
        {SKU:"82-38333", Quantity:288, Item:"Lip balm", Description:"Lip balm. Flavor: Cherry."},
        {SKU:"21-38485", Quantity:177, Item:"Ping Pong Ball", Description:""},
        {SKU:"83-38285", Quantity:87, Item:"Hockey Puck", Description:"Glow-in-the-dark hockey puck."}
    ],

    addresses: [
        {name:"John A. Smith", address:"1236 Some Street", city:"San Francisco", state:"CA", amount:5, active:"yes", colors:["red"], last_login:"4/19/2007"},
        {name:"Joan B. Jones", address:"3271 Another Ave", city:"New York", state:"NY", amount:3, active:"no", colors:["red","blue"], last_login:"2/15/2006"},
        {name:"Bob C. Uncle", address:"9996 Random Road", city:"Los Angeles", state:"CA", amount:0, active:"maybe", colors:["green"], last_login:"1/23/2004"},
        {name:"John D. Smith", address:"1623 Some Street", city:"San Francisco", state:"CA", amount:5, active:"yes", colors:["red"], last_login:"4/19/2007"},
        {name:"Joan E. Jones", address:"3217 Another Ave", city:"New York", state:"NY", amount:3, active:"no", colors:["red","blue"], last_login:"2/15/2006"},
        {name:"Bob F. Uncle", address:"9899 Random Road", city:"Los Angeles", state:"CA", amount:0, active:"maybe", colors:["green"], last_login:"1/23/2004"},
        {name:"John G. Smith", address:"1723 Some Street", city:"San Francisco", state:"CA", amount:5, active:"yes", colors:["red"], last_login:"4/19/2007"},
        {name:"Joan H. Jones", address:"3241 Another Ave", city:"New York", state:"NY", amount:3, active:"no", colors:["red","blue"], last_login:"2/15/2006"},
        {name:"Bob I. Uncle", address:"9909 Random Road", city:"Los Angeles", state:"CA", amount:0, active:"maybe", colors:["green"], last_login:"1/23/2004"},
        {name:"John J. Smith", address:"1623 Some Street", city:"San Francisco", state:"CA", amount:5, active:"yes", colors:["red"], last_login:"4/19/2007"},
        {name:"Joan K. Jones", address:"3721 Another Ave", city:"New York", state:"NY", amount:3, active:"no", colors:["red","blue"], last_login:"2/15/2006"},
        {name:"Bob L. Uncle", address:"9989 Random Road", city:"Los Angeles", state:"CA", amount:0, active:"maybe", colors:["green"], last_login:"1/23/2004"},
        {name:"John M. Smith", address:"1293 Some Street", city:"San Francisco", state:"CA", amount:5, active:"yes", colors:["red"], last_login:"4/19/2007"},
        {name:"Joan N. Jones", address:"3621 Another Ave", city:"New York", state:"NY", amount:3, active:"no", colors:["red","blue"], last_login:"2/15/2006"},
        {name:"Bob O. Uncle", address:"9959 Random Road", city:"Los Angeles", state:"CA", amount:0, active:"maybe", colors:["green"], last_login:"1/23/2004"},
        {name:"John P. Smith", address:"6123 Some Street", city:"San Francisco", state:"CA", amount:5, active:"yes", colors:["red"], last_login:"4/19/2007"},
        {name:"Joan Q. Jones", address:"3281 Another Ave", city:"New York", state:"NY", amount:3, active:"no", colors:["red","blue"], last_login:"2/15/2006"},
        {name:"Bob R. Uncle", address:"9989 Random Road", city:"Los Angeles", state:"CA", amount:0, active:"maybe", colors:["green"], last_login:"1/23/2004"}
    ],

    bookorders: [
        {id:"po-0167", date:new Date(1980, 2, 24), quantity:1, amount:4, title:"A Book About Nothing",
        description: "Lorem ipsum dolor sit amet consectetuer Quisque ipsum suscipit Aenean ligula. Accumsan molestie nibh dui orci vitae auctor nec pulvinar ligula elit."},
        {id:"po-0783", date:new Date("January 3, 1983"), quantity:0, amount:12.12345, title:"The Meaning of Life",
        description: "Vestibulum scelerisque wisi adipiscing turpis odio Phasellus euismod id orci tristique. Hendrerit sem dictum volutpat cursus pretium dui vitae tincidunt Vivamus Aenean."},
        {id:"po-0297", date:new Date(1978, 11, 12), quantity:12, amount:1.25, title:"This Book Was Meant to Be Read Aloud",
        description: "Malesuada pellentesque nibh magna nisl tincidunt wisi dui Nam nunc convallis. Adipiscing leo augue Nulla tellus nec eros metus cursus pretium Sed."},
        {id:"po-1482", date:new Date("March 11, 1985"), quantity:6, amount:3.5, title:"Read Me Twice",
        description: "Libero justo pede nibh tincidunt ut tempus metus et Vestibulum vel. Sem justo morbi lacinia dui turpis In Lorem dictumst volutpat cursus."}
    ],
    
    stateAbbrs: [
        "AL","AK","AZ","AR","CA","CO","CT","DE","DC","FL","GA","HI",
        "ID","IL","IN","IA","KS","KY","LA","ME","MD","MA","MI","MN","MS",
        "MO","MT","NE","NV","NH","NJ","NM","NY","NC","ND","OH","OK","OR",
        "PA","RI","SC","SD","TN","TX","UT","VT","VA","WA","WV","WI","WY"
    ],
    
    areacodes: [
        {areacode: "201", state: "New Jersey"},
        {areacode: "202", state: "Washington, DC"},
        {areacode: "203", state: "Connecticut"},
        {areacode: "204", state: "Manitoba, Canada"},
        {areacode: "205", state: "Alabama"},
        {areacode: "206", state: "Washington"},
        {areacode: "207", state: "Maine"},

        {areacode: "208", state: "Idaho"},
        {areacode: "209", state: "California"},
        {areacode: "210", state: "Texas"},
        {areacode: "212", state: "New York"},
        {areacode: "213", state: "California"},
        {areacode: "214", state: "Texas"},

        {areacode: "215", state: "Pennsylvania"},
        {areacode: "216", state: "Ohio"},
        {areacode: "217", state: "Illinois"},
        {areacode: "218", state: "Minnesota"},
        {areacode: "219", state: "Indiana"},
        {areacode: "224", state: "Illinois"},

        {areacode: "225", state: "Louisiana"},
        {areacode: "227", state: "Maryland"},
        {areacode: "228", state: "Mississippi"},
        {areacode: "229", state: "Georgia"},
        {areacode: "231", state: "Michigan"},
        {areacode: "234", state: "Ohio"},

        {areacode: "239", state: "Florida"},
        {areacode: "240", state: "Maryland"},
        {areacode: "242", state: "Bahamas"},
        {areacode: "246", state: "Barbados"},
        {areacode: "248", state: "Michigan"},
        {areacode: "250", state: "British Columbia"},

        {areacode: "251", state: "Alabama"},
        {areacode: "252", state: "North Carolina"},
        {areacode: "253", state: "Washington"},
        {areacode: "254", state: "Texas"},
        {areacode: "256", state: "Alabama"},
        {areacode: "260", state: "Indiana"},

        {areacode: "262", state: "Wisconsin"},
        {areacode: "264", state: "Anguilla"},
        {areacode: "267", state: "Pennsylvania"},
        {areacode: "268", state: "Antigua and Barbuda"},
        {areacode: "269", state: "Michigan"},
        {areacode: "270", state: "Kentucky"},

        {areacode: "276", state: "Virginia"},
        {areacode: "281", state: "Texas"},
        {areacode: "283", state: "Ohio"},
        {areacode: "284", state: "British Virgin Islands"},
        {areacode: "289", state: "Ontario"},
        {areacode: "301", state: "Maryland"},

        {areacode: "302", state: "Delaware"},
        {areacode: "303", state: "Colorado"},
        {areacode: "304", state: "West Virginia"},
        {areacode: "305", state: "Florida"},
        {areacode: "306", state: "Saskatchewan, Canada"},
        {areacode: "307", state: "Wyoming"},

        {areacode: "308", state: "Nebraska"},
        {areacode: "309", state: "Illinois"},
        {areacode: "310", state: "California"},
        {areacode: "312", state: "Illinois"},
        {areacode: "313", state: "Michigan"},
        {areacode: "314", state: "Missouri"},

        {areacode: "315", state: "New York"},
        {areacode: "316", state: "Kansas"},
        {areacode: "317", state: "Indiana"},
        {areacode: "318", state: "Louisiana"},
        {areacode: "319", state: "Iowa"},
        {areacode: "320", state: "Minnesota"},

        {areacode: "321", state: "Florida"},
        {areacode: "323", state: "California"},
        {areacode: "330", state: "Ohio"},
        {areacode: "331", state: "Illinois"},
        {areacode: "334", state: "Alabama"},
        {areacode: "336", state: "North Carolina"},

        {areacode: "337", state: "Louisiana"},
        {areacode: "339", state: "Massachusetts"},
        {areacode: "340", state: "US Virgin Islands"},
        {areacode: "345", state: "Cayman Islands"},
        {areacode: "347", state: "New York"},
        {areacode: "351", state: "Massachusetts"},

        {areacode: "352", state: "Florida"},
        {areacode: "360", state: "Washington"},
        {areacode: "361", state: "Texas"},
        {areacode: "386", state: "Florida"},
        {areacode: "401", state: "Rhode Island"},
        {areacode: "402", state: "Nebraska"},

        {areacode: "403", state: "Alberta, Canada"},
        {areacode: "404", state: "Georgia"},
        {areacode: "405", state: "Oklahoma"},
        {areacode: "406", state: "Montana"},
        {areacode: "407", state: "Florida"},
        {areacode: "408", state: "California"},

        {areacode: "409", state: "Texas"},
        {areacode: "410", state: "Maryland"},
        {areacode: "412", state: "Pennsylvania"},
        {areacode: "413", state: "Massachusetts"},
        {areacode: "414", state: "Wisconsin"},
        {areacode: "415", state: "California"},

        {areacode: "416", state: "Ontario, Canada"},
        {areacode: "417", state: "Missouri"},
        {areacode: "418", state: "Quebec, Canada"},
        {areacode: "419", state: "Ohio"},
        {areacode: "423", state: "Tennessee"},
        {areacode: "424", state: "California"},

        {areacode: "425", state: "Washington"},
        {areacode: "434", state: "Virginia"},
        {areacode: "435", state: "Utah"},
        {areacode: "440", state: "Ohio"},
        {areacode: "441", state: "Bermuda"},
        {areacode: "443", state: "Maryland"},

        {areacode: "445", state: "Pennsylvania"},
        {areacode: "450", state: "Quebec, Canada"},
        {areacode: "464", state: "Illinois"},
        {areacode: "469", state: "Texas"},
        {areacode: "470", state: "Georgia"},
        {areacode: "473", state: "Grenada"},

        {areacode: "475", state: "Connecticut"},
        {areacode: "478", state: "Georgia"},
        {areacode: "479", state: "Arkansas"},
        {areacode: "480", state: "Arizona"},
        {areacode: "484", state: "Pennsylvania"},
        {areacode: "501", state: "Arkansas"},

        {areacode: "502", state: "Kentucky"},
        {areacode: "503", state: "Oregon"},
        {areacode: "504", state: "Louisiana"},
        {areacode: "505", state: "New Mexico"},
        {areacode: "506", state: "New Brunswick, Canada"},
        {areacode: "507", state: "Minnesota"},

        {areacode: "508", state: "Massachusetts"},
        {areacode: "509", state: "Washington"},
        {areacode: "510", state: "California"},
        {areacode: "512", state: "Texas"},
        {areacode: "513", state: "Ohio"},
        {areacode: "514", state: "Quebec, Canada"},

        {areacode: "515", state: "Iowa"},
        {areacode: "516", state: "New York"},
        {areacode: "517", state: "Michigan"},
        {areacode: "518", state: "New York"},
        {areacode: "519", state: "Ontario, Canada"},
        {areacode: "520", state: "Arizona"},

        {areacode: "530", state: "California"},
        {areacode: "540", state: "Virginia"},
        {areacode: "541", state: "Oregon"},
        {areacode: "551", state: "New Jersey"},
        {areacode: "557", state: "Missouri"},
        {areacode: "559", state: "California"},

        {areacode: "561", state: "Florida"},
        {areacode: "562", state: "California"},
        {areacode: "563", state: "Iowa"},
        {areacode: "564", state: "Washington"},
        {areacode: "567", state: "Ohio"},
        {areacode: "570", state: "Pennsylvania"},

        {areacode: "571", state: "Virginia"},
        {areacode: "573", state: "Missouri"},
        {areacode: "574", state: "Indiana"},
        {areacode: "580", state: "Oklahoma"},
        {areacode: "585", state: "New York"},
        {areacode: "586", state: "Michigan"},

        {areacode: "601", state: "Mississippi"},
        {areacode: "602", state: "Arizona"},
        {areacode: "603", state: "New Hampshire"},
        {areacode: "604", state: "British Columbia, Canada"},
        {areacode: "605", state: "South Dakota"},
        {areacode: "606", state: "Kentucky"},

        {areacode: "607", state: "New York"},
        {areacode: "608", state: "Wisconsin"},
        {areacode: "609", state: "New Jersey"},
        {areacode: "610", state: "Pennsylvania"},
        {areacode: "612", state: "Minnesota"},
        {areacode: "613", state: "Ontario, Canada"},

        {areacode: "614", state: "Ohio"},
        {areacode: "615", state: "Tennessee"},
        {areacode: "616", state: "Michigan"},
        {areacode: "617", state: "Massachusetts"},
        {areacode: "618", state: "Illinois"},
        {areacode: "619", state: "California"},

        {areacode: "620", state: "Kansas"},
        {areacode: "623", state: "Arizona"},
        {areacode: "626", state: "California"},
        {areacode: "630", state: "Illinois"},
        {areacode: "631", state: "New York"},
        {areacode: "636", state: "Missouri"},

        {areacode: "641", state: "Iowa"},
        {areacode: "646", state: "New York"},
        {areacode: "647", state: "Ontario, Canada"},
        {areacode: "649", state: "Turks and Caicos Islands"},
        {areacode: "650", state: "California"},
        {areacode: "651", state: "Minnesota"},

        {areacode: "660", state: "Missouri"},
        {areacode: "661", state: "California"},
        {areacode: "662", state: "Mississippi"},
        {areacode: "664", state: "Montserrat"},
        {areacode: "667", state: "Maryland"},
        {areacode: "670", state: "CNMI"},

        {areacode: "671", state: "Guam"},
        {areacode: "678", state: "Georgia"},
        {areacode: "682", state: "Texas"},
        {areacode: "701", state: "North Dakota"},
        {areacode: "702", state: "Nevada"},
        {areacode: "703", state: "Virginia"},

        {areacode: "704", state: "North Carolina"},
        {areacode: "705", state: "Ontario, Canada"},
        {areacode: "706", state: "Georgia"},
        {areacode: "707", state: "California"},
        {areacode: "708", state: "Illinois"},
        {areacode: "709", state: "Newfoundland, Canada"},

        {areacode: "712", state: "Iowa"},
        {areacode: "713", state: "Texas"},
        {areacode: "714", state: "California"},
        {areacode: "715", state: "Wisconsin"},
        {areacode: "716", state: "New York"},
        {areacode: "717", state: "Pennsylvania"},

        {areacode: "718", state: "New York"},
        {areacode: "719", state: "Colorado"},
        {areacode: "720", state: "Colorado"},
        {areacode: "724", state: "Pennsylvania"},
        {areacode: "727", state: "Florida"},
        {areacode: "731", state: "Tennessee"},

        {areacode: "732", state: "New Jersey"},
        {areacode: "734", state: "Michigan"},
        {areacode: "737", state: "Texas"},
        {areacode: "740", state: "Ohio"},
        {areacode: "754", state: "Florida"},
        {areacode: "757", state: "Viriginia"},

        {areacode: "758", state: "St. Lucia"},
        {areacode: "760", state: "California"},
        {areacode: "763", state: "Minnesota"},
        {areacode: "765", state: "Indiana"},
        {areacode: "767", state: "Dominica"},
        {areacode: "770", state: "Georgia"},

        {areacode: "772", state: "Florida"},
        {areacode: "773", state: "Illinois"},
        {areacode: "774", state: "Massachusetts"},
        {areacode: "775", state: "Nevada"},
        {areacode: "778", state: "British Columbia, Canada"},
        {areacode: "780", state: "Alberta, Canada"},

        {areacode: "781", state: "Massachusetts"},
        {areacode: "784", state: "St. Vincent &amp; Gren."},
        {areacode: "785", state: "Kansas"},
        {areacode: "786", state: "Florida"},
        {areacode: "787", state: "Puerto Rico"},

        {areacode: "801", state: "Utah"},
        {areacode: "802", state: "Vermont"},
        {areacode: "803", state: "South Carolina"},
        {areacode: "804", state: "Virginia"},
        {areacode: "805", state: "California"},
        {areacode: "806", state: "Texas"},

        {areacode: "807", state: "Ontario, Canada"},
        {areacode: "808", state: "Hawaii"},
        {areacode: "809", state: "Dominican Republic"},
        {areacode: "810", state: "Michigan"},
        {areacode: "812", state: "Indiana"},
        {areacode: "813", state: "Florida"},

        {areacode: "814", state: "Pennsylvania"},
        {areacode: "815", state: "Illinois"},
        {areacode: "816", state: "Missouri"},
        {areacode: "817", state: "Texas"},
        {areacode: "818", state: "California"},
        {areacode: "819", state: "Quebec, Canada"},

        {areacode: "828", state: "North Carolina"},
        {areacode: "830", state: "Texas"},
        {areacode: "831", state: "California"},
        {areacode: "832", state: "Texas"},
        {areacode: "835", state: "Pennsylvania"},
        {areacode: "843", state: "South Carolina"},

        {areacode: "845", state: "New York"},
        {areacode: "847", state: "Illinois"},
        {areacode: "848", state: "New Jersey"},
        {areacode: "850", state: "Florida"},
        {areacode: "856", state: "New Jersey"},
        {areacode: "857", state: "Massachusetts"},

        {areacode: "858", state: "California"},
        {areacode: "859", state: "Kentucky"},
        {areacode: "860", state: "Connecticut"},
        {areacode: "862", state: "New Jersey"},
        {areacode: "863", state: "Florida"},
        {areacode: "864", state: "South Carolina"},

        {areacode: "865", state: "Tennessee"},
        {areacode: "867", state: "Yukon, NW Territories, Canada"},
        {areacode: "868", state: "Trinidad and Tobago"},
        {areacode: "869", state: "St. Kitts &amp; Nevis"},
        {areacode: "870", state: "Arkansas"},

        {areacode: "872", state: "Illinois"},
        {areacode: "876", state: "Jamaica"},
        {areacode: "878", state: "Pennsylvania"},
        {areacode: "901", state: "Tennessee"},
        {areacode: "902", state: "Nova Scotia, Canada"},
        {areacode: "903", state: "Texas"},

        {areacode: "904", state: "Florida"},
        {areacode: "905", state: "Ontario, Canada"},
        {areacode: "906", state: "Michigan"},
        {areacode: "907", state: "Alaska"},
        {areacode: "908", state: "New Jersey"},
        {areacode: "909", state: "California"},

        {areacode: "910", state: "North Carolina"},
        {areacode: "912", state: "Georgia"},
        {areacode: "913", state: "Kansas"},
        {areacode: "914", state: "New York"},
        {areacode: "915", state: "Texas"},
        {areacode: "916", state: "California"},

        {areacode: "917", state: "New York"},
        {areacode: "918", state: "Oklahoma"},
        {areacode: "919", state: "North Carolina"},
        {areacode: "920", state: "Wisconsin"},
        {areacode: "925", state: "California"},
        {areacode: "928", state: "Arizona"},

        {areacode: "931", state: "Tennessee"},
        {areacode: "936", state: "Texas"},
        {areacode: "937", state: "Ohio"},
        {areacode: "939", state: "Puerto Rico"},
        {areacode: "940", state: "Texas"},
        {areacode: "941", state: "Florida"},

        {areacode: "947", state: "Michigan"},
        {areacode: "949", state: "California"},
        {areacode: "952", state: "Minnesota"},
        {areacode: "954", state: "Florida"},
        {areacode: "956", state: "Texas"},
        {areacode: "959", state: "Connecticut"},

        {areacode: "970", state: "Colorado"},
        {areacode: "971", state: "Oregon"},
        {areacode: "972", state: "Texas"},
        {areacode: "973", state: "New Jersey"},
        {areacode: "975", state: "Missouri"},
        {areacode: "978", state: "Massachusetts"},

        {areacode: "979", state: "Texas"},
        {areacode: "980", state: "North Carolina"},
        {areacode: "984", state: "North Carolina"},
        {areacode: "985", state: "Louisiana"},
        {areacode: "989", state: "Michigan"}
    ]
};
